netapp_ontap.models.storage_unit_space API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.storage_unit_space`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class StorageUnitSpaceSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the StorageUnitSpace object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `efficiency_ratio: float GET`

    The storage efficiency ratio of the storage unit without snapshots. (Logical Used / Used)

    Example: 2.5

  `physical_used: Size GET`

    The number of bytes consumed on the disk by the storage unit, excluding snapshots.

    Example: 1073741824

  `physical_used_by_snapshots: Size GET`

    The number of bytes consumed on the disk by the storage unit's snapshots. This property has been replaced by `space.snapshot.used`.

    Example: 1073741824

  `size: Size GET`

    The total provisioned size of the storage unit. The storage unit size can be increased but not decreased using the /api/storage/luns or /api/storage/namespaces endpoints.
    The maximum and minimum sizes listed here are the absolute maximum and absolute minimum sizes, in bytes. The actual minimum and maximum sizes vary depending on the ONTAP version, ONTAP platform and the available space.
    For more information, see Size properties in the docs section of the ONTAP REST API documentation.

    Example: 1073741824

  `snapshot: StorageUnitSpaceSnapshot GET POST PATCH`

    The snapshot field of the storage_unit_space.

  `used: Size GET`

    The amount of space consumed by the main data stream of the storage unit.
    This value is the total space consumed, including filesystem overhead, but excluding prefix and suffix streams. Due to internal filesystem overhead and the many ways SAN filesystems and applications utilize blocks within a LUN or namespace, this value does not necessarily reflect actual consumption/availability from the perspective of the filesystem or application. Without specific knowledge of how the LUN or namespace blocks are utilized outside of ONTAP, this property should not be used as an indicator for an out-of-space condition.
    For more information, see Size properties in the docs section of the ONTAP REST API documentation.